.. _core:

===================
Core functionality
===================

Ensemble
========

.. autoclass:: qp.Ensemble
    :members:
    :undoc-members:

    
Factory 
=======
       

.. autoclass:: qp.factory.Factory
    :members:
    :undoc-members:
    